# trinity

**DOI:** [10.5281/zenodo.8096026](https://doi.org/10.5281/zenodo.8096026)

## Available Versions
- **Version 2.15.1**
  - [Download](https://zenodo.org/record/8096027/files/trinity_2.15.1.img)
  - **MD5:** `1c5d12a96dc37de347438d26ed8dccf8`
  - **DOI:** [10.5281/zenodo.8096027](https://doi.org/10.5281/zenodo.8096027)
  - **Size:** 2612.69 MB
  - **Binaries:** 0 available

## Binaries (1 total)

```Trinity,TrinityStats.pl,align_and_estimate_abundance.pl,abundance_estimates_to_matrix.pl```
